import { jsxs, Fragment, jsx } from 'react/jsx-runtime';
import { cx } from '@emotion/css';
import { useState } from 'react';
import { reportInteraction } from '@grafana/runtime';
import { useTheme2, Button, Spinner, Toggletip, RadioButtonList, TextArea } from '@grafana/ui';
import { buildVisualQueryFromString } from '../../parsing.js';
import { getStyles } from './PromQail.js';

const suggestionOptions = [
  { label: "Yes", value: "yes" },
  { label: "No", value: "no" }
];
const explationOptions = [
  { label: "Too vague", value: "too vague" },
  { label: "Too technical", value: "too technical" },
  { label: "Inaccurate", value: "inaccurate" },
  { label: "Other", value: "other" }
];
function QuerySuggestionItem(props) {
  const { querySuggestion, order, queryExplain, historical, onChange, closeDrawer, last, allSuggestions, prompt } = props;
  const [showExp, updShowExp] = useState(false);
  const [gaveExplanationFeedback, updateGaveExplanationFeedback] = useState(false);
  const [gaveSuggestionFeedback, updateGaveSuggestionFeedback] = useState(false);
  const [suggestionFeedback, setSuggestionFeedback] = useState({
    radioInput: "",
    text: ""
  });
  const [explanationFeedback, setExplanationFeedback] = useState({
    radioInput: "",
    text: ""
  });
  const theme = useTheme2();
  const styles = getStyles(theme);
  const { query, explanation } = querySuggestion;
  const feedbackToggleTip = (type) => {
    const updateRadioFeedback = (value) => {
      if (type === "explanation") {
        setExplanationFeedback({
          ...explanationFeedback,
          radioInput: value
        });
      } else {
        setSuggestionFeedback({
          ...suggestionFeedback,
          radioInput: value
        });
      }
    };
    const updateTextFeedback = (e) => {
      if (type === "explanation") {
        setExplanationFeedback({
          ...explanationFeedback,
          text: e.currentTarget.value
        });
      } else {
        setSuggestionFeedback({
          ...suggestionFeedback,
          text: e.currentTarget.value
        });
      }
    };
    const disabledButton = () => type === "explanation" ? !explanationFeedback.radioInput : !suggestionFeedback.radioInput;
    const questionOne = type === "explanation" ? "Why was the explanation not helpful?" : "Were the query suggestions helpful?";
    return /* @__PURE__ */ jsxs("div", { className: styles.suggestionFeedback, children: [
      /* @__PURE__ */ jsxs("div", { children: [
        /* @__PURE__ */ jsxs("div", { className: styles.feedbackQuestion, children: [
          /* @__PURE__ */ jsx("h6", { children: questionOne }),
          /* @__PURE__ */ jsx("i", { children: "(Required)" })
        ] }),
        /* @__PURE__ */ jsx(
          RadioButtonList,
          {
            name: "default",
            options: type === "explanation" ? explationOptions : suggestionOptions,
            value: type === "explanation" ? explanationFeedback.radioInput : suggestionFeedback.radioInput,
            onChange: updateRadioFeedback
          }
        )
      ] }),
      /* @__PURE__ */ jsxs("div", { className: cx(type === "explanation" && styles.explationTextInput), children: [
        type !== "explanation" && /* @__PURE__ */ jsx("div", { className: styles.feedbackQuestion, children: /* @__PURE__ */ jsx("h6", { children: "How can we improve the query suggestions?" }) }),
        /* @__PURE__ */ jsx(
          TextArea,
          {
            type: "text",
            "aria-label": "Promqail suggestion text",
            placeholder: "Enter your feedback",
            value: type === "explanation" ? explanationFeedback.text : suggestionFeedback.text,
            onChange: updateTextFeedback,
            cols: 100
          }
        )
      ] }),
      /* @__PURE__ */ jsx("div", { className: styles.submitFeedback, children: /* @__PURE__ */ jsx(
        Button,
        {
          variant: "primary",
          size: "sm",
          disabled: disabledButton(),
          onClick: () => {
            if (type === "explanation") {
              explanationFeedbackEvent(
                explanationFeedback.radioInput,
                explanationFeedback.text,
                querySuggestion,
                historical,
                prompt
              );
              updateGaveExplanationFeedback(true);
            } else {
              suggestionFeedbackEvent(
                suggestionFeedback.radioInput,
                suggestionFeedback.text,
                allSuggestions != null ? allSuggestions : "",
                historical,
                prompt
              );
              updateGaveSuggestionFeedback(true);
            }
          },
          children: "Submit"
        }
      ) })
    ] });
  };
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsxs("div", { className: styles.querySuggestion, children: [
      /* @__PURE__ */ jsx("div", { title: query, className: cx(styles.codeText, styles.longCode), children: `${order}.  ${query}` }),
      /* @__PURE__ */ jsx("div", { className: styles.useButton, children: /* @__PURE__ */ jsx(
        Button,
        {
          variant: "primary",
          size: "sm",
          onClick: () => {
            reportInteraction("grafana_prometheus_promqail_use_query_button_clicked", {
              query: querySuggestion.query
            });
            const pvq = buildVisualQueryFromString(querySuggestion.query);
            onChange(pvq.query);
            closeDrawer();
          },
          children: "Use"
        }
      ) })
    ] }),
    /* @__PURE__ */ jsxs("div", { children: [
      /* @__PURE__ */ jsx(
        Button,
        {
          fill: "text",
          variant: "secondary",
          icon: showExp ? "angle-up" : "angle-down",
          onClick: () => {
            updShowExp(!showExp);
            queryExplain(order - 1);
          },
          className: cx(styles.bodySmall),
          size: "sm",
          children: "Explainer"
        }
      ),
      !showExp && order !== 5 && /* @__PURE__ */ jsx("div", { className: styles.textPadding }),
      showExp && !querySuggestion.explanation && /* @__PURE__ */ jsx("div", { className: styles.center, children: /* @__PURE__ */ jsx(Spinner, {}) }),
      showExp && querySuggestion.explanation && /* @__PURE__ */ jsxs(Fragment, { children: [
        /* @__PURE__ */ jsxs("div", { className: cx(styles.bodySmall, styles.explainPadding), children: [
          /* @__PURE__ */ jsx("div", { className: styles.textPadding, children: "This query is trying to answer the question:" }),
          /* @__PURE__ */ jsx("div", { className: styles.textPadding, children: explanation }),
          /* @__PURE__ */ jsxs("div", { className: styles.textPadding, children: [
            "Learn more with this",
            " ",
            /* @__PURE__ */ jsx(
              "a",
              {
                className: styles.doc,
                href: "https://prometheus.io/docs/prometheus/latest/querying/examples/#query-examples",
                target: "_blank",
                rel: "noopener noreferrer",
                children: "Prometheus doc"
              }
            )
          ] }),
          /* @__PURE__ */ jsxs("div", { className: cx(styles.rightButtons, styles.secondaryText), children: [
            "Was this explanation helpful?",
            /* @__PURE__ */ jsx("div", { className: styles.floatRight, children: !gaveExplanationFeedback ? /* @__PURE__ */ jsxs(Fragment, { children: [
              /* @__PURE__ */ jsx(
                Button,
                {
                  fill: "outline",
                  variant: "secondary",
                  size: "sm",
                  className: styles.leftButton,
                  onClick: () => {
                    explanationFeedbackEvent("Yes", "", querySuggestion, historical, prompt);
                    updateGaveExplanationFeedback(true);
                  },
                  children: "Yes"
                }
              ),
              /* @__PURE__ */ jsx(
                Toggletip,
                {
                  "aria-label": "Suggestion feedback",
                  content: feedbackToggleTip("explanation"),
                  placement: "bottom-end",
                  closeButton: true,
                  children: /* @__PURE__ */ jsx(Button, { fill: "outline", variant: "secondary", size: "sm", children: "No" })
                }
              )
            ] }) : "Thank you for your feedback!" })
          ] })
        ] }),
        !last && /* @__PURE__ */ jsx("hr", {})
      ] }),
      last && /* @__PURE__ */ jsx("div", { className: cx(styles.feedbackStyle), children: !gaveSuggestionFeedback ? /* @__PURE__ */ jsx(
        Toggletip,
        {
          "aria-label": "Suggestion feedback",
          content: feedbackToggleTip("suggestion"),
          placement: "bottom-end",
          closeButton: true,
          children: /* @__PURE__ */ jsx(Button, { fill: "outline", variant: "secondary", size: "sm", children: "Give feedback on suggestions" })
        }
      ) : (
        // do this weird thing because the toggle tip doesn't allow an extra close function
        /* @__PURE__ */ jsx(Button, { fill: "outline", variant: "secondary", size: "sm", disabled: true, children: "Thank you for your feedback!" })
      ) })
    ] })
  ] });
}
function explanationFeedbackEvent(radioInputFeedback, textFeedback, querySuggestion, historical, prompt) {
  const event = "grafana_prometheus_promqail_explanation_feedback";
  reportInteraction(event, {
    helpful: radioInputFeedback,
    textFeedback,
    suggestionType: historical ? "historical" : "AI",
    query: querySuggestion.query,
    explanation: querySuggestion.explanation,
    prompt
  });
}
function suggestionFeedbackEvent(radioInputFeedback, textFeedback, allSuggestions, historical, prompt) {
  const event = "grafana_prometheus_promqail_suggestion_feedback";
  reportInteraction(event, {
    helpful: radioInputFeedback,
    textFeedback,
    suggestionType: historical ? "historical" : "AI",
    allSuggestions,
    prompt
  });
}

export { QuerySuggestionItem };
//# sourceMappingURL=QuerySuggestionItem.js.map
